/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deploy.deployable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.ee.deploy.impl.helper.DeployableHelper;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.ee.deploy.api.deployable.factory.IFileDeployableFactoryManager;
import org.ow2.util.ee.deploy.api.deployable.factory.XmlFileDeployableFactory;
import org.ow2.util.plan.deploy.deployable.impl.DeploymentPlanDeployableImpl;
import org.ow2.util.plan.deploy.deployable.impl.RepositoryDeployableImpl;
import org.ow2.util.ee.deploy.impl.deployable.factory.DefaultFileDeployableFactoryManager;
import org.ow2.util.ee.deploy.impl.deployable.factory.XmlFileDeployableFactoryImpl;


/**
 * Activator for the deploy bundle.
 * @author Mickaël LEDUQUE
 */
public class PlanDeployableActivator implements BundleActivator  {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(PlanDeployableActivator.class);

    /**
     * Deployment plan namespace.
     */
    private static final String DEPLOYMENTPLAN_NS =
    "http://jonas.ow2.org/ns/deployment-plan/1.0";

    /**
     * repositories namespace.
     */
    private static final String REPOSITORY_NS =
    "http://jonas.ow2.org/ns/deployment-plan/repositories/1.0";

    /**
     * The ServiceRegistration object for the registered IFileDeployableFactoryManager object.
     */
    private ServiceRegistration factoryManagerServiceRegistration = null;

    /**
     * The ServiceRegistration object for the registered XmlFileDeployableFactory object.
     */
    private ServiceRegistration fileDeployableFactoryServiceRegistration;

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        /* Will register a DefaultFileDeployableFactoryManager
         * and add an XmlFileDeployableFactory with deployment plan
         * and repository deployable classes registered */
        IFileDeployableFactoryManager fileDeployableFactoryManager = new DefaultFileDeployableFactoryManager();
        factoryManagerServiceRegistration = context.registerService(
                IFileDeployableFactoryManager.class.getName(),
                fileDeployableFactoryManager,
                null);

        XmlFileDeployableFactory fileDeployableFactory = new XmlFileDeployableFactoryImpl();
        fileDeployableFactoryServiceRegistration = context.registerService(
                XmlFileDeployableFactory.class.getName(),
                fileDeployableFactory,
                null);

        fileDeployableFactory.registerFileDeployable(DeploymentPlanDeployableImpl.class,
                                                     DEPLOYMENTPLAN_NS);
        fileDeployableFactory.registerFileDeployable(RepositoryDeployableImpl.class,
                                                     REPOSITORY_NS);

        fileDeployableFactoryManager.addFileDeployableFactory(fileDeployableFactory);

        /* Unfortunately, DeployableHelper is a mainly static class */
        DeployableHelper.setFileDeployableFactory(fileDeployableFactoryManager);
        logger.debug("FileDeployableFactory service registered and used in DeployableHelper");
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        DeployableHelper.setFileDeployableFactory(null);
        fileDeployableFactoryServiceRegistration.unregister();
        factoryManagerServiceRegistration.unregister();
        logger.debug("FileDeployableFactory service unregistered");
    }

}
