/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.impl.condition;

import javax.script.ScriptEngine;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptException;

import org.ow2.util.plan.deployer.api.condition.EvaluationException;
import org.ow2.util.plan.deployer.api.condition.IConditionEvaluator;

/**
 * A {@code ScriptConditionEvaluator} is ...
 *
 * @author Guillaume Sauthier
 */
public class ScriptConditionEvaluator implements IConditionEvaluator {

    private ScriptEngineFactory scriptEngineFactory;

    public void setScriptEngineFactory(ScriptEngineFactory scriptEngineFactory) {
        this.scriptEngineFactory = scriptEngineFactory;
    }

    public boolean evaluate(String condition) throws EvaluationException {

        // Create a new engine for this evaluation
        ScriptEngine engine = scriptEngineFactory.getScriptEngine();

        try {

            // Determine if the result should be interpreted as true or false
            return isTrue(engine.eval(condition));

        } catch (ScriptException e) {
            throw new EvaluationException("Error during script evaluation", e);
        }
    }

    private boolean isTrue(Object o) {
        if (o == null) {
            return false;
        }

        if (o instanceof Boolean) {
            return (Boolean) o;
        }

        // If the value is not null, this is sufficient
        return true;
    }
}
