/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.script;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

import javax.script.ScriptEngine;
import javax.script.ScriptException;

import org.osgi.framework.BundleContext;
import org.ow2.util.plan.deployer.impl.condition.script.RhinoScriptEngineFactory;

/**
 * A {@code OSGiAwareScriptEngineFactory} is ...
 *
 * @author Guillaume Sauthier
 */
public class OSGiAwareScriptEngineFactory extends RhinoScriptEngineFactory {

    private BundleContext bundleContext;

    public OSGiAwareScriptEngineFactory(BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    @Override
    public ScriptEngine getScriptEngine() {
        ScriptEngine engine = super.getScriptEngine();

        engine.put("bundleContext", bundleContext);

        evaluateResource(engine, "Converters.js");
        evaluateResource(engine, "BundleInfo.js");
        evaluateResource(engine, "ServiceInfo.js");
        evaluateResource(engine, "osgi-environment.js");

        return engine;
    }

    private void evaluateResource(ScriptEngine engine, String resourceName) {
        Reader reader = null;
        try {
            reader = getResourceReader(resourceName);
            engine.eval(reader);
        } catch (ScriptException e) {
            throw new RuntimeException("Cannot execute script " + resourceName, e);
        } catch (IOException e) {
            throw new RuntimeException("Cannot load script " + resourceName, e);
        } finally {
            if (reader != null) {
                try {
                    reader.close();
                } catch (IOException e) {
                    // Ignored
                }
            }
        }
    }

    private Reader getResourceReader(String name) throws IOException {
        InputStream is = OSGiAwareScriptEngineFactory.class.getResourceAsStream(name);
        if (is == null) {
            throw new IOException("Cannot load resource '" + name + "' from "
            + OSGiAwareScriptEngineFactory.class);
        }
        return new InputStreamReader(is);
    }

}
