/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.impl.condition.script;

import javax.script.ScriptEngine;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptEngineManager;

import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertNull;
import static org.testng.Assert.assertTrue;

/**
 * A {@code RhinoScriptEngineFactoryTestCase} is ...
 *
 * @author Guillaume Sauthier
 */
public class RhinoScriptEngineFactoryTestCase {

    private ScriptEngine scriptEngine;

    @BeforeMethod
    public void setUp() throws Exception {
        RhinoScriptEngineFactory rhino = new RhinoScriptEngineFactory();
        rhino.setScriptEngineFactory(getPlatformJavaScriptEngineFactory());

        scriptEngine = rhino.getScriptEngine();
    }

    private ScriptEngineFactory getPlatformJavaScriptEngineFactory() {
        ScriptEngineManager manager = new ScriptEngineManager();
        ScriptEngine engine = manager.getEngineByName("JavaScript");
        return engine.getFactory();
    }

    @Test
    public void testSystemPropertyInfo() throws Exception {
        assertTrue((Boolean) scriptEngine.eval("systemProperty('unknown').unset"));
        assertTrue((Boolean) scriptEngine.eval("systemProperty('user.dir').set"));

        assertEquals(scriptEngine.eval("systemProperty('user.dir').value"),
                     System.getProperty("user.dir"));

        assertNull(scriptEngine.eval("systemProperty('unknown').value"));

    }

}
