/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.impl.obr.activator;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.Constants;
import org.osgi.framework.ServiceEvent;
import org.osgi.framework.ServiceListener;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactory;
import org.ow2.util.plan.fetcher.impl.obr.ObrResourceFetcherFactory;
import org.ow2.util.plan.repository.api.IRepositoryManager;

/**
 * 
 * @author Mickaël LEDUQUE
 *
 */
public class ObrFetcherActivator implements BundleActivator, ServiceListener {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(ObrFetcherActivator.class);

    /**
     * The bundle context.
     */
    private BundleContext bundleContext = null;

    /**
     * The fetcher factory.
     */
    private ObrResourceFetcherFactory fetcherFactory = null;

    /**
     * The fetcher factory registration reference.
     */
    private ServiceRegistration obrFetcherFactoryRegistration = null;

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        this.bundleContext = context;
        this.fetcherFactory = new ObrResourceFetcherFactory();
        this.fetcherFactory.setBundleContext(this.bundleContext);
        

        ServiceReference repositoryManagerRef = context.getServiceReference(
                                                IRepositoryManager.class.getName());
        if (repositoryManagerRef != null) {
            this.fetcherFactory.setRepositoryManager(
                        (IRepositoryManager)context.getService(repositoryManagerRef));
        }

        this.obrFetcherFactoryRegistration = context.registerService(
                        IResourceFetcherFactory.class.getName(),
                        this.fetcherFactory, null);

        /* registers self as service events listener */
        context.addServiceListener(this, "(" + Constants.OBJECTCLASS +
                            "=" + IRepositoryManager.class.getName() + ")");
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        this.obrFetcherFactoryRegistration.unregister();

    }

    public void serviceChanged(ServiceEvent event) {
        ServiceReference serviceRef = event.getServiceReference();
        Object serviceObject = this.bundleContext.getService(serviceRef);
        if (serviceObject instanceof IRepositoryManager) {
            IRepositoryManager repositoryManager = (IRepositoryManager) serviceObject;
            switch (event.getType()) {
                case ServiceEvent.REGISTERED :
                    if (this.fetcherFactory.getRepositoryManager() == null) {
                        this.fetcherFactory.setRepositoryManager(repositoryManager);
                        logger.debug("The repository manager is set to '{0}'.", repositoryManager);
                    }
                    break;
                case ServiceEvent.UNREGISTERING :
                    this.fetcherFactory.setRepositoryManager(null);
                    logger.debug("The repository manager is unset");
                    break;
                default : break;
            }
        }
        
    }

}
