/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.monitor.impl.activator;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.monitor.api.IResourceMonitor;
import org.ow2.util.plan.monitor.impl.ResourceMonitorImpl;

/**
 * Activator for the resource monitor bundle.
 * @author Mickaël LEDUQUE
 */
public class MonitorActivator implements BundleActivator {
    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(MonitorActivator.class);

    /**
     * Service registration for the resource monitor.
     */
    private ServiceRegistration monitorRegistration = null;

    /**
     * The resource monitor.
     */
    private IResourceMonitor resourceMonitor = null;

    /**
     * @{inheritDoc}
     */
    public void start(BundleContext bc) throws Exception {
        this.resourceMonitor = new ResourceMonitorImpl();
        this.monitorRegistration = bc.registerService(IResourceMonitor.class.getName(),
                this.resourceMonitor, null);
        logger.debug("registered a Resource Monitor : {0}", this.resourceMonitor);
    }

    /**
     * @{inheritDoc}
     */
    public void stop(BundleContext bc) throws Exception {
        this.monitorRegistration.unregister();
        logger.debug("Resource Monitor unregistered");
    }

}
