/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.reader;

import javax.xml.bind.ValidationEvent;
import javax.xml.bind.ValidationEventHandler;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * ValidationEventHandler used by Reader classes.
 * @author mleduque
 */
public class ReaderValidationEventHandler implements ValidationEventHandler {

    /**
     * The logger.
     */
    private static Log logger = LogFactory.getLog(ReaderValidationEventHandler.class);

    /**
     * Tolerance level for parsing errors.
     */
    private int laxLevel;

    /**
     * Constructs a ReaderValidationEventHandler object.
     * @param laxLevel Tolerance level for parsing errors.
     */
    public ReaderValidationEventHandler(int laxLevel) {
        if (laxLevel < 0 || laxLevel > 3) {
            throw new IllegalArgumentException("bad value for laxlevel");
        }
        this.laxLevel = laxLevel;
    }

    /**
     * {@inheritDoc}
     * @param event
     * @return
     */
    public boolean handleEvent(ValidationEvent event) {
        if (this.laxLevel < event.getSeverity()) {
            logger.error(
                            "xml file could not be read, message: {0}",
                            event.getMessage());
            return false;
        } else {
            logger.debug(
                            "read error, attempting to continue; message: {0}",
                            event.getMessage());
            return true;
        }
    }
}