/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.reader.repository;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import javax.xml.XMLConstants;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.transform.sax.SAXSource;
import javax.xml.validation.SchemaFactory;

import org.ow2.util.plan.bindings.repository.Repositories;
import org.ow2.util.plan.reader.AbsReader;
import org.ow2.util.plan.reader.ReaderException;
import org.xml.sax.InputSource;

/**
 * Implementation for the IRepositoryDataReader interface.
 * @author Mickaël LEDUQUE
 */
public class RepositoryDataReaderImpl extends AbsReader implements IRepositoryDataReader {

    /**
     * XML binding classes used by RepositoryDataReaders.
     */
    private final static Class[] REPOSITORIES_CLASSES = {
        org.ow2.util.plan.bindings.repository.ObjectFactory.class
    };

    /**
     * Location of the schema resource.
     */
    private final static String REPOSITORY_XSD = "repositories-1.0.xsd";

    /**
     * No-args constructor.
     * @throws JAXBException when the unmarshaller or schema build failed.
     */
    public RepositoryDataReaderImpl() throws Exception {
        super();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void initUnmarshallClasses() {
        unmarshallClasses = REPOSITORIES_CLASSES;
    }

    /**
     * {@inheritDoc}
     */
    public Repositories readRepositories(final File file) throws IOException,
                                ReaderException {
        JAXBElement jaxbElement = null;
        try {
            jaxbElement = getRootElement(file);
        } catch (JAXBException e) {
            throw new ReaderException(e);
        }

        Object elementValue = jaxbElement.getValue();
        if (elementValue instanceof Repositories) {
            return (Repositories)elementValue;
        } else {
            throw new ReaderException("Bad root element for repository file.");
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void buildUnmarshallerSchema() throws Exception {
        SchemaFactory sf = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
        // Build the schema for validation.
        InputStream is = this.schemaStreamFactory.getSchemaStream(REPOSITORY_XSD);
        if (is == null) {
            throw new Exception("Cannot read Repository XSD resource");
        }
        SAXSource ss = new SAXSource(new InputSource(is));

        this.unmarshallerSchema = sf.newSchema(ss);
    }
}
