/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.reader.test;

import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

import java.io.File;

import org.ow2.util.plan.bindings.deploymentplan.Deployment;
import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlan;
import org.ow2.util.plan.bindings.deploymentplan.maven2.Maven2Deployment;
import org.ow2.util.plan.bindings.deploymentplan.obr.ObrDeployment;
import org.ow2.util.plan.bindings.deploymentplan.url.UrlDeployment;
import org.ow2.util.plan.bindings.schemastream.SchemaStreamFactoryImpl;
import org.ow2.util.plan.reader.ReaderException;
import org.ow2.util.plan.reader.ReaderValidationEventHandler;
import org.ow2.util.plan.reader.plan.IPlanReader;
import org.ow2.util.plan.reader.plan.PlanReaderImpl;
import org.testng.annotations.Test;

/**
 * Test class for the Deployment Plans reader.
 * @author Mickaël LEDUQUE
 */
@Test(sequential = true)
public class DeploymentPlanLoadTest {

    /**
     * The valid plan that is being read.
     */
    DeploymentPlan plan = null;

    /**
     * The list of deployments in the plan.
     */
    java.util.List<Deployment> deployments = null;

    /**
     * The deployment plan reader.
     */
    IPlanReader reader = null;

    @Test
    public void getReader() throws Exception {
        this.reader = new PlanReaderImpl();
        this.reader.setSchemaStreamFactory(new SchemaStreamFactoryImpl());
        this.reader.setValidation(true);

    }

    @Test(dependsOnMethods = { "getReader" }, expectedExceptions = { ReaderException.class })
    public void loadMustFail() throws Exception {
        this.reader.setValidationEventHandler(
                new ReaderValidationEventHandler(1));
        this.reader.readPlan(new File(
                "target/test-classes/invalid/not-a-deployment-plan.xml"));

    }


     @Test(dependsOnMethods = { "getReader" }, expectedExceptions = { ReaderException.class })
    public void incompleteMavenLoad() throws Exception {
        this.reader.setValidationEventHandler(
                new ReaderValidationEventHandler(1));
        synchronized (this.reader) {
            this.reader.readPlan(new File(
                    "target/test-classes/invalid/incomplete-maven.xml"));
        }

    }

    @Test(dependsOnMethods = { "getReader" })
    public void loadDeploymentPlan() throws Exception {
        this.reader.setValidationEventHandler(
                new ReaderValidationEventHandler(1));
        synchronized (this.reader) {
            this.plan = this.reader.readPlan(new File(
                    "target/test-classes/deployment-plan.xml"));
        }

        assertTrue(this.plan.isAtomic(),
                "deployment-plan@atomic has wrong value");
        assertNotNull(this.plan.getDeployments(),
                "no deployment-plan@*:deployment !");
        this.deployments = this.plan.getDeployments();
    }

    @Test(dependsOnMethods = { "loadDeploymentPlan" })
    public void countDeployments() throws Exception {
        if (this.deployments.size() != 3) {
            throw new Exception("deployment-plan/* has bad deployment number: "
                    + this.deployments.size() + " expected 3");
        }
    }

    @Test(dependsOnMethods = { "countDeployments" })
    public void checkTypes() throws Exception {
        if (!(this.deployments.get(0) instanceof Maven2Deployment)) {
            throw new Exception(
                    "deployment-plan/deployment[0] has wrong type: "
                            + this.deployments.get(0).getClass().getName());
        }
        if (!(this.deployments.get(1) instanceof ObrDeployment)) {
            throw new Exception(
                    "deployment-plan/deployment[1] has wrong type: "
                            + this.deployments.get(0).getClass().getName());
        }
        if (!(this.deployments.get(2) instanceof UrlDeployment)) {
            throw new Exception(
                    "deployment-plan/deployment[2] has wrong type: "
                            + this.deployments.get(0).getClass().getName());
        }
    }

}
