/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.repository.impl;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.repository.api.IRepositoryManager;

/**
 * Activator for the repository bundle.
 * @author Mickaël LEDUQUE
 *
 */
public class RepositoryActivator implements BundleActivator {
    
    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(RepositoryActivator.class);

    /**
     * The ServiceRegistration object for the registered XmlHelper object.
     */
    private ServiceRegistration repositoryManagerServiceRegistration = null;

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        IRepositoryManager repositoryManager = new CustomRepositoryManager();
        repositoryManagerServiceRegistration = context.registerService(
                IRepositoryManager.class.getName(), repositoryManager, null);
        logger.debug("Repository Manager {0} registered", repositoryManager);
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        repositoryManagerServiceRegistration.unregister();
        logger.debug("Repository Manager unregistered");
    }

}
