/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.repository.impl;

import java.io.Serializable;
import java.util.Comparator;

import org.ow2.util.plan.bindings.repository.Repository;

/**
 * Comparator used to sort repositories. The local repositories are the first
 * repositories returned by the iterator because the repository URL starts with
 * the protocol 'file' (due to lexicographical order).
 * If protocols are equal, repositories are sorted by id.
 * @author Francois Fornaciari
 */
public class RepositoryComparator implements Comparator<Repository>, Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6156316510585074091L;

    /**
     * Compare two given repositories.
     * @param repository1 the repository to compare
     * @param repository2 the second repository
     * @return compare of the two URLs of the repositories
     */
    public int compare(final Repository repository1, final Repository repository2) {
        // Extracts the repository URL protocols and compare them
        int result = repository1.getUrl().substring(0, 4).compareTo(repository2.getUrl().substring(0, 4));
        if (result == 0) {
            // Compares the repository Ids
            result = repository1.getId().compareTo(repository2.getId());
        }
        return result;
    }
}
